@@ -44,7 +44,6 @@
 #define OPEN_SIGNAL_NAME        "open_status_menu"
 #define CLOSE_SIGNAL_NAME        "close_status_menu"
 
-
 /* UI Style guide */
 #define STATUS_AREA_HEIGHT 56
 #define MINIMUM_STATUS_AREA_WIDTH 112
@@ -109,19 +108,19 @@ button_press_event_cb (GtkWidget      *widget,
 
 static DBusHandlerResult
 hd_dbus_signal_handler (DBusConnection *conn, DBusMessage *msg, void *data)
-{ 
-	HDStatusAreaPrivate *priv = (HDStatusAreaPrivate *)data;
+{
+    HDStatusAreaPrivate *priv = (HDStatusAreaPrivate *)data;
     if (dbus_message_is_signal(msg, TASKNAV_SIGNAL_INTERFACE, OPEN_SIGNAL_NAME))
-   	{
-		gtk_widget_show (priv->status_menu);
-	   	return DBUS_HANDLER_RESULT_HANDLED;
-   	}
-    if (dbus_message_is_signal(msg, TASKNAV_SIGNAL_INTERFACE, CLOSE_SIGNAL_NAME))
-   	{
-		gtk_widget_hide (priv->status_menu);
-	   	return DBUS_HANDLER_RESULT_HANDLED;
-   	}
-	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+    {
+        gtk_widget_show (priv->status_menu);
+        return DBUS_HANDLER_RESULT_HANDLED;
+    }
+    else if (dbus_message_is_signal(msg, TASKNAV_SIGNAL_INTERFACE, CLOSE_SIGNAL_NAME))
+    {
+        gtk_widget_hide (priv->status_menu);
+        return DBUS_HANDLER_RESULT_HANDLED;
+    }
+    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
 static gboolean
@@ -256,17 +255,14 @@ hd_status_area_init (HDStatusArea *status_area)
    * program is full-screen) */
   g_signal_connect (G_OBJECT (status_area), "configure-event",
                     G_CALLBACK (configure_event_cb), status_area);
-
   dbus_error_init (&derror);
   connection = dbus_bus_get (DBUS_BUS_SESSION, &derror);
   if (!connection) {
-	  dbus_error_free (&derror);
-	  g_warning ("%s: failed to connect to the system bus", __func__);
+      dbus_error_free (&derror);
+      g_warning ("%s: failed to connect to the system bus", __func__);
   } else {
-
-	  dbus_bus_add_match (connection, "type='signal', interface='" TASKNAV_SIGNAL_INTERFACE "'", NULL);
-	  dbus_connection_add_filter (connection, hd_dbus_signal_handler,  priv, NULL);
-
+      dbus_bus_add_match (connection, "type='signal', interface='" TASKNAV_SIGNAL_INTERFACE "'", NULL);
+      dbus_connection_add_filter (connection, hd_dbus_signal_handler,  priv, NULL);
   }
 }
 
